=============
diffcalc-core
=============


.. image:: https://img.shields.io/pypi/v/diffcalc-core.svg
        :target: https://pypi.python.org/pypi/diffcalc-core

.. image:: https://dev.azure.com/iraklisikharulidze/diffcalc-core/_apis/build/status/DiamondLightSource.diffcalc-core?branchName=main
        :target: https://dev.azure.com/iraklisikharulidze/diffcalc-core/_build/latest?definitionId=2&branchName=main

.. image:: https://codecov.io/gh/DiamondLightSource/diffcalc-core/branch/main/graph/badge.svg?token=I9LINSTT0N
        :target: https://codecov.io/gh/DiamondLightSource/diffcalc-core

.. image:: https://img.shields.io/lgtm/alerts/g/DiamondLightSource/diffcalc-core.svg?logo=lgtm&logoWidth=18
        :target: https://lgtm.com/projects/g/DiamondLightSource/diffcalc-core/alerts/

.. image:: https://img.shields.io/lgtm/grade/python/g/DiamondLightSource/diffcalc-core.svg?logo=lgtm&logoWidth=18
        :target: https://lgtm.com/projects/g/DiamondLightSource/diffcalc-core/context:python

.. image:: https://readthedocs.org/projects/diffcalc-core/badge/?version=latest
        :target: https://diffcalc-core.readthedocs.io/en/latest/?version=latest
        :alt: Documentation Status

.. image:: https://img.shields.io/pypi/pyversions/diffcalc-core.svg
        :target: https://pypi.python.org/pypi/diffcalc-core
        :alt: Supported Python versions

.. image:: https://img.shields.io/badge/code%20style-black-000000.svg
        :target: https://github.com/ambv/black
        :alt: Code style: black

Python implementation of angle calculations for six-circle X-ray or neutron
diffractometer that follows a model described in [You1999]_.


* Free software: Apache Software License 2.0
* Documentation: https://diffcalc-core.readthedocs.io.


This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

References
----------

.. [You1999] H. You. *Angle calculations for a '4S+2D' six-circle diffractometer.*
   J. Appl. Cryst. (1999). **32**, 614-623. `(pdf link)
   <http://journals.iucr.org/j/issues/1999/04/00/hn0093/hn0093.pdf>`__.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
